%bcond_with systemd
%bcond_without check

Name:           containerd
Version:        1.7.20
Release:        1%{_dist_release}%{?with_systemd:.systemd}
Summary:        An open and reliable container runtime
Group:          virtualization
Vendor:         Project Vine
Distribution:   Vine Linux

# Generated by go-vendor-tools
# SourceLicense:  Apache-2.0
License:        Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND ISC AND MIT AND MPL-2.0
URL:            https://github.com/containerd/containerd
Source0:        https://github.com/containerd/containerd/archive/refs/tags/v%{version}.tar.gz#/containerd-%{version}.tar.gz

Patch:          0001-Makefile-fix-GO_LDFLAGS-quoting.patch

%if %{with man}
BuildRequires:  /usr/bin/go-md2man
%endif
BuildRequires:  btrfs-progs-devel
BuildRequires:  libseccomp-devel
BuildRequires:  make
BuildRequires:  golang

Requires:       runc

%description
Containerd is an industry-standard container runtime with an emphasis on
simplicity, robustness and portability. It is available as a daemon for Linux
and Windows, which can manage the complete container lifecycle of its host
system: image transfer and storage, container execution and supervision,
low-level storage and network attachments, etc.


%prep
%setup -q
%autopatch -p1
# Replace default bin directory
sed -i "s|/usr/local/bin/containerd|/usr/bin/containerd|" containerd.service


%build
GO_LDFLAGS="-s -w" GO_BUILDFLAGS="-E -trimpath"
%global makeflags %{expand:\\
    DATADIR=%{_datadir} \\
    DESTDIR=%{buildroot} \\
    MANDIR=%{_mandir} \\
    PREFIX=%{_prefix} \\
    SHIM_CGO_ENABLED=1 \\
    BUILDTAGS="apparmor selinux seccomp" \\
    VERSION=%{version} \\
    REVISION=%{release} \\
}
%if %{with man}
%make_build %{makeflags} binaries man
%else
%make_build %{makeflags} binaries
%endif


%install
%if %{with man}
%make_build %{makeflags} install install-man
%else
%make_build %{makeflags} install
%endif

# Set up dummy configuration.
install -d -m755 %{buildroot}/%{_sysconfdir}/%{name}
echo "# See containerd-config.toml(5) for documentation." >%{buildroot}/%{_sysconfdir}/%{name}/config.toml

%if %{with systemd}
install -Dpm 0644 containerd.service -t %{buildroot}%{_unitdir}
%endif


%check
%if %{with check}
%make_build %{makeflags} test
%endif


%files
%license vendor/modules.txt
%doc ROADMAP.md ADOPTERS.md BUILDING.md README.md RELEASES.md SCOPE.md
%{_bindir}/ctr
%{_bindir}/containerd
%{_bindir}/containerd-stress
%{_bindir}/containerd-shim*
%if %{with man}
%{_mandir}/man5/containerd-config.toml.5*
%{_mandir}/man8/ctr.8*
%{_mandir}/man8/containerd.8*
%{_mandir}/man8/containerd-config.8*
%endif
%dir %{_sysconfdir}/containerd
%config(noreplace) %{_sysconfdir}/containerd/config.toml
%if %{with systemd}
%{_unitdir}/containerd.service
%endif


%changelog
* Thu Jul 18 2024 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.7.20-1
- new upstream release.

* Mon Jul 15 2024 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.7.19-1
- initial build for Vine Linux.
